using GLib;
using Gee;

using SrcPkgManager;

namespace NDCCore {

	public class Profile : GLib.Object {
		public string name { get; set; }
		public string email { get; set; }

		public Profile (string uname = "Marlon", string umail = "mlores@uci.cu") {
			name = uname;
			email = umail;
		}
	}

	public class Project: GLib.Object {	
		public string name { get; set; }
		public ArrayList<Package> packages { get; set; }

		public Project(string pname){
			name = pname;
			packages = new ArrayList<Package>();
		}

		public void add_package(Package pkg) {
			packages.add(pkg);
		}

		public void new_package(string name, string ver, string rev) {
			var pkg = new Package(name, ver, rev);
			add_package (pkg);
		}
	}

	public class WorkSpace: GLib.Object {	
		public string name { get; set; }
		public ArrayList<Project> projects { get; set;}

		public WorkSpace (string ws_name) {
			name = ws_name;
			projects = new ArrayList<Project>();
		}

		public void add_project(Project prj) {
			projects.add(prj);
		}

		public void new_project(string name) {
			var prj = new Project(name);
			add_project (prj);
		}
	}
	
	public class NDC : GLib.Object {
		private ArrayList<WorkSpace> work_spaces;
		private ArrayList<Profile> user_profiles;
	 
		public NDC () {
			work_spaces = new ArrayList<WorkSpace>();
			user_profiles = new ArrayList<Profile>();
		}

		public ArrayList<WorkSpace> get_work_spaces() {
			return work_spaces;
		}
		
		public void add_work_space (string ws_name) {
			WorkSpace work_space = new WorkSpace(ws_name);
			work_spaces.add(work_space);
			GLib.Process.spawn_command_line_async("mkdir -p "+get_work_spaces()[0].name);  
		}
		
		public ArrayList<Profile> get_user_profiles() {
			return user_profiles;
		}
		
		public void add_profile (Profile p) {
			user_profiles.add(p);
		}
		
	}
}
